@@ -28,17 +28,17 @@ def config(tester, base_url):
     """配置测试人员、API Base Url"""
     if tester:
         CONFIG_DATA['tester'] = tester
-        click.echo(click.style(f'当前配置的测试人员：{tester}', fg='blue', bold=True))
+        click.echo(click.style(f'当前配置的测试人员：{tester}', fg='bright_cyan', bold=True))
     if base_url:
         CONFIG_DATA['base_url'] = base_url
-        click.echo(click.style(f'当前配置的 Base Url：{base_url}', fg='blue', bold=True))
+        click.echo(click.style(f'当前配置的 Base Url：{base_url}', fg='bright_cyan', bold=True))
     if tester or base_url:
         CONFIG.put(CONFIG_DATA)
     else:
-        click.echo(click.style(f'tester={CONFIG_DATA.get("tester") or "未配置"}', fg='blue', bold=True))
-        click.echo(click.style(f'base_url={CONFIG_DATA.get("base_url")}', fg='blue', bold=True))
+        click.echo(click.style(f'tester={CONFIG_DATA.get("tester") or "未配置"}', fg='bright_cyan', bold=True))
+        click.echo(click.style(f'base_url={CONFIG_DATA.get("base_url")}', fg='bright_cyan', bold=True))
         click.echo(
-            click.style(f'请输入 unicase --tester <name> 或 unicase --base-url <base url> 进行配置', fg='blue', bold=True))
+            click.style(f'请输入 unicase --tester <name> 或 unicase --base-url <base url> 进行配置', fg='bright_cyan', bold=True))
 
 
 @cli.command()
@@ -50,8 +50,8 @@ def create(name):
 
     select = Choice('请选择用例所属的迭代: (按 <esc> 退出) ',
                     list(iterations.keys()),
-                    icon_style=StringStyle(fore=Fore.blue),
-                    selected_style=StringStyle(fore=Fore.blue))
+                    icon_style=StringStyle(fore=Fore.lightcyan),
+                    selected_style=StringStyle(fore=Fore.lightcyan))
 
     choice = select.get_choice()
     if choice:
@@ -74,6 +74,6 @@ def create(name):
 def upload(ctx, name, type):
     """上传 Excel 用例到 TAPD"""
     # if CONFIG_DATA.get('tester') is None:
-    #     click.echo(click.style('上传用例需要先配置测试人员', fg='blue', bold=True))
+    #     click.echo(click.style('上传用例需要先配置测试人员', fg='bright_cyan', bold=True))
     #     ctx.invoke(config)
-    click.echo(click.style('功能正在开发中...', fg='blue', bold=True))
+    click.echo(click.style('功能正在开发中...', fg='bright_cyan', bold=True))
